==> training-facade-3.2.1.1-sources.jar: cn/smarthse/radiationTraining/modules/training/vo/training/TrainHomeCropExportVo.java <==
package cn.smarthse.radiationTraining.modules.training.vo.training;

import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import java.io.Serializable;

/**
 * 用人单位培训档案 Vo
 *
 * @author chuhy
 * @date 2022/9/26
 */
@Data
public class TrainHomeCropExportVo implements Serializable {
    private static final long serialVersionUID = -2616734071268068052L;

    @ApiModelProperty(value="用人单位")
    private String unitName;

    @ApiModelProperty(value="统一社会信用代码")
    private String creditCode;

    @ApiModelProperty(value="行政区划名称")
    private String areaName;

    @ApiModelProperty(value="行业名称")
    private String industryName;

    @ApiModelProperty(value="培训次数")
    private Integer trainNum;

    @ApiModelProperty(value="主要负责人有效证书数")
    private Integer majorInvalidCertNum;

    @ApiModelProperty(value="'职业卫生管理人员'有效证书数")
    private Integer managerInvalidCertNum;

    @ApiModelProperty(value="'主要负责人'过期证书数")
    private Integer majorOverDueNum;

    @ApiModelProperty(value="'职业卫生管理人员'过期证书数")
    private Integer managerOverDueNum;

    // @ApiModelProperty(value="主要负责人证书状态(0-未取证；1-全部过期；2-部分过期；3-全部有效)")
    // private Integer majorStatus;
    //
    // @ApiModelProperty(value="职业卫生管理人员证书状态(0-未取证；1-全部过期；2-部分过期；3-全部有效)")
    // private Integer managerStatus;
    //
    // public String getMajorStatus() {
    //     if (majorStatus == null)
    //         return null;
    //
    //     if (majorStatus == 0){
    //         return "未取证";
    //     } else if (majorStatus == 1){
    //         return "全部过期";
    //     } else if (majorStatus == 2){
    //         return "部分过期";
    //     } else if (majorStatus == 3){
    //         return "全部有效";
    //     }
    //
    //     return null;
    // }
    //
    // public String getManagerStatus() {
    //     if (managerStatus == null)
    //         return null;
    //     if (managerStatus == 0){
    //         return "未取证";
    //     } else if (managerStatus == 1){
    //         return "全部过期";
    //     } else if (managerStatus == 2){
    //         return "部分过期";
    //     } else if (managerStatus == 3){
    //         return "全部有效";
    //     }
    //
    //     return null;
    // }
}

==> training-facade-3.2.2.4-sources.jar: cn/smarthse/radiationTraining/modules/training/vo/training/TrainHomeCropExportVo.java <==
package cn.smarthse.radiationTraining.modules.training.vo.training;

import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import java.io.Serializable;

/**
 * 用人单位培训档案 Vo
 *
 * @author chuhy
 * @date 2022/9/26
 */
@Data
public class TrainHomeCropExportVo implements Serializable {
    private static final long serialVersionUID = -2616734071268068052L;

    @ApiModelProperty(value="用人单位")
    private String unitName;

    @ApiModelProperty(value="统一社会信用代码")
    private String creditCode;

    @ApiModelProperty(value="行政区划名称")
    private String areaName;

    @ApiModelProperty(value="行业名称")
    private String industryName;

    @ApiModelProperty(value="培训次数")
    private Integer trainNum;

    @ApiModelProperty(value="主要负责人有效证书数")
    private Integer majorInvalidCertNum;

    @ApiModelProperty(value="'职业卫生管理人员'有效证书数")
    private Integer managerInvalidCertNum;

    @ApiModelProperty(value="'主要负责人'过期证书数")
    private Integer majorOverDueNum;

    @ApiModelProperty(value="'职业卫生管理人员'过期证书数")
    private Integer managerOverDueNum;


    @ApiModelProperty(value="'非医放射人员'有效证书数")
    private Integer nonMedicalInvalidCertNum;

    @ApiModelProperty(value="'非医放射人员'过期证书数")
    private Integer nonMedicalOverDueNum;

    // @ApiModelProperty(value="主要负责人证书状态(0-未取证；1-全部过期；2-部分过期；3-全部有效)")
    // private Integer majorStatus;
    //
    // @ApiModelProperty(value="职业卫生管理人员证书状态(0-未取证；1-全部过期；2-部分过期；3-全部有效)")
    // private Integer managerStatus;
    //
    // public String getMajorStatus() {
    //     if (majorStatus == null)
    //         return null;
    //
    //     if (majorStatus == 0){
    //         return "未取证";
    //     } else if (majorStatus == 1){
    //         return "全部过期";
    //     } else if (majorStatus == 2){
    //         return "部分过期";
    //     } else if (majorStatus == 3){
    //         return "全部有效";
    //     }
    //
    //     return null;
    // }
    //
    // public String getManagerStatus() {
    //     if (managerStatus == null)
    //         return null;
    //     if (managerStatus == 0){
    //         return "未取证";
    //     } else if (managerStatus == 1){
    //         return "全部过期";
    //     } else if (managerStatus == 2){
    //         return "部分过期";
    //     } else if (managerStatus == 3){
    //         return "全部有效";
    //     }
    //
    //     return null;
    // }
}
